% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/SCATEpipeline.R
\name{SCATEpipeline}
\alias{SCATEpipeline}
\title{SCATE Pipeline}
\usage{
SCATEpipeline(
  bamfile,
  genome = "hg19",
  cellclunum = NULL,
  CREclunum = NULL,
  datapath = NULL,
  ncores = 1,
  perplexity = 30,
  example = FALSE
)
}
\arguments{
\item{bamfile}{Character vector of bam files to be processed}

\item{genome}{Character variable of either "hg19" or "mm10".}

\item{cellclunum}{Numeric variable giving the number of cell clusters when clustering cells. If NULL the cluster number will be determined automatically.}

\item{CREclunum}{Numeric variable giving the number of CRE clusters when running SCATE. If NULL the cluster number will be determined automatically.}

\item{datapath}{Character variable of the path to the customized database (eg myfolder/database.rds). The database can be made using 'makedatabase' function. If not null, 'genome' is ignored.}

\item{ncores}{Numeric variable of number of cores to use. If NULL, the maximum number of cores is used.}

\item{perplexity}{Numeric variable specifying perplexity of tSNE. Reduce perplexity when sample size is small.}

\item{example}{An indicator of whether this is running an example or real data. When running a real data, this should be set as FALSE. The default is FALSE.}
}
\value{
A list of three elements. First element is a list generated by cellcluster function, and it contains the cell clustering results. Second element is a matrix generated by SCATE function. Each column is the SCATE result for one cell cluster. Column names indicate the cluster id. Third element is a list of peaks. Each element is the peak list for one cluster. Name of the element indicates the name of the cluster.
}
\description{
SCATE pipeline of reading in bam, clustering cell, and performing SCATE
}
\details{
This function takes as input a list of bam files. It then read in the bam files, cluster cells, and performs SCATE for each cell cluster
}
\examples{
f <- list.files(paste0(system.file(package="SCATEData"),"/extdata/"),full.names = TRUE,pattern='.bam$')
#Users need to set CREclunum to be NULL in real applications.
SCATEpipeline(f[1],genome="hg19",CREclunum=156,perplexity=0.1,example=TRUE) 
}
\author{
Zhicheng Ji, Weiqiang Zhou, Wenpin Hou, Hongkai Ji* <whou10@jhu.edu>
}
